@@ -607,7 +607,7 @@ static void colourgui_connect_handlers(ColourGUI * cg)
 	CG_CONNECT(cg, on_use_custom_colours_toggled);
 }
 
-ColourGUI *colourgui_open(const char *scheme_name)
+ColourGUI *colourgui_open(const char *scheme_name, GdkScreen *scrn)
 {
 	ColourGUI *cg;
 	char *title;
@@ -621,6 +621,8 @@ ColourGUI *colourgui_open(const char *scheme_name)
 	cg = g_hash_table_lookup(colourgui_being_edited, scheme_name);
 	if (cg)
 	{
+	    if (scrn)
+            gtk_window_set_screen(GTK_WINDOW(cg->widget), scrn);
 		gtk_window_present(GTK_WINDOW(cg->widget));
 		return cg;
 	}
@@ -634,6 +636,8 @@ ColourGUI *colourgui_open(const char *scheme_name)
 		"Colour_Scheme_Editor", NULL);
 	g_assert(cg->glade);
 	cg->widget = glade_xml_get_widget(cg->glade, "Colour_Scheme_Editor");
+    if (scrn)
+        gtk_window_set_screen(GTK_WINDOW(cg->widget), scrn);
 	title = g_strdup_printf(_("ROXTerm Colour Scheme \"%s\""), scheme_name);
 	gtk_window_set_title(GTK_WINDOW(cg->widget), title);
 	g_free(title);
