@@ -104,7 +104,7 @@ dynamic_options_unref(DynamicOptions * dynopts, const char *profile_name)
 }
 
 static GList *dynopts_add_path_contents_to_list(GList *list, const char *path,
-                const char *family)
+                const char *family, gboolean sorted)
 {
     GError *err = NULL;
     char *dirname = g_build_filename(path, family, NULL);
@@ -145,10 +145,14 @@ static GList *dynopts_add_path_contents_to_list(GList *list, const char *path,
         }
     }
     g_free(dirname);
+    if (sorted)
+    {
+        list = g_list_sort(list, (GCompareFunc) dynamic_options_strcmp);
+    }
     return list;
 }
 
-char **dynamic_options_list(DynamicOptions *dynopts)
+char **dynamic_options_list_full(DynamicOptions *dynopts, gboolean sorted)
 {
     int i;
     const char * const *paths = options_file_get_pathv();
@@ -161,7 +165,7 @@ char **dynamic_options_list(DynamicOptions *dynopts)
     for (i = 0; paths[i]; ++i)
     {
         list = dynopts_add_path_contents_to_list(list, paths[i],
-                dynopts->family);
+                dynopts->family, sorted);
     }
 
     nmemb = g_list_length(list);
@@ -186,4 +190,21 @@ void dynamic_options_rename(DynamicOptions *dynopts,
     g_hash_table_insert(dynopts->profiles, g_strdup(new_name), opts);
 }
 
+int dynamic_options_strcmp(const char *s1, const char *s2)
+{
+    char *u1, *u2;
+    int result;
+    
+    if (!g_strcmp0(s1, "Default"))
+        return g_strcmp0(s2, "Default") ? -1 : 0;
+    else if (!g_strcmp0(s2, "Default"))
+        return 1;
+    u1 = s1 ? g_utf8_casefold(s1, -1) : g_strdup("");
+    u2 = s2 ? g_utf8_casefold(s2, -1) : g_strdup("");
+    result = g_utf8_collate(u1, u2);
+    g_free(u2);
+    g_free(u1);
+    return result;
+}
+
 /* vi:set sw=4 ts=4 noet cindent cino= */
