@@ -27,7 +27,7 @@
 char *logo_find(void)
 {
 	if (global_options_appdir)
-		return g_build_filename(global_options_appdir, ".DirIcon", NULL);
+		return g_build_filename(global_options_appdir, "roxterm.svg", NULL);
 	else
 		return g_build_filename(ICON_DIR, "roxterm.svg", NULL);
 }
