@@ -19,6 +19,7 @@
 
 #include "defns.h"
 
+#include <stdio.h>
 #include <locale.h>
 
 #include <gdk/gdk.h>
@@ -49,6 +50,8 @@ static gboolean main_quit_handler(gpointer data)
 #define ROXTERM_DBUS_INTERFACE RTDBUS_INTERFACE
 #define ROXTERM_DBUS_METHOD_NAME "NewTerminal"
 
+extern char **environ;
+
 static DBusMessage *create_dbus_message(int argc, char **argv,
         const char *display)
 {
@@ -58,6 +61,13 @@ static DBusMessage *create_dbus_message(int argc, char **argv,
     message = rtdbus_method_new(ROXTERM_DBUS_NAME, ROXTERM_DBUS_OBJECT_PATH,
             ROXTERM_DBUS_INTERFACE,
             ROXTERM_DBUS_METHOD_NAME, DBUS_TYPE_INVALID);
+    for (n = 0; environ[n]; ++n);
+    message = rtdbus_append_args(message,
+            DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, RTDBUS_ARG(environ), n,
+            DBUS_TYPE_INVALID);
+    if (!message)
+        return NULL;
+    
     for (n = 0; message && n < argc; ++n)
     {
         message = rtdbus_append_args(message,
@@ -77,12 +87,13 @@ static DBusMessage *create_dbus_message(int argc, char **argv,
 static int run_via_dbus(DBusMessage *message)
 {
     int result = 0;
-
+    
     if (!message)
         return -1;
+    
     /* New roxterm command may have been run in a different directory
      * from original instance */
-    if (!global_options_directory)
+    if (!result && !global_options_directory)
     {
         char *cwd = GET_CURRENT_DIR();
         const char *d = "-d";
@@ -114,7 +125,19 @@ static int run_via_dbus(DBusMessage *message)
         }
     }
     if (!result)
-        result = rtdbus_send_message_with_reply(message) ? 0 : 1;
+    {
+        /* The reply to the NewTerminal message can't include whether it
+         * launched successfully because we don't know that until we fork
+         * the command after an idle, and D-BUS won't let us defer the reply to
+         * after an idle.
+         *
+         * Removing the reply prevents the error message reported in
+         * <http://p.sf.net/roxterm/gi5kdI9QrPZ>
+         * at the expense of regressing
+         * <http://p.sf.net/roxterm/EfNoUkwW>
+         */
+        result = rtdbus_send_message(message) ? 0 : -1;
+    }
     return result;
 }
 
@@ -122,10 +145,11 @@ static DBusHandlerResult new_term_listener(DBusConnection *connection,
         DBusMessage *message, void *user_data)
 {
     DBusError derror;
+    char **env;
     char **argv;
     int argc;
-    int n;
     const char *display = NULL;
+    DBusMessageIter iter;
 
     dbus_error_init(&derror);
 
@@ -134,22 +158,25 @@ static DBusHandlerResult new_term_listener(DBusConnection *connection,
     {
         return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;    
     }
-    argv = rtdbus_get_message_args_as_strings(message);
+    dbus_message_iter_init(message, &iter);
+    env = rtdbus_get_message_arg_string_array(&iter);
+    argv = rtdbus_get_message_args_as_strings(&iter);
     for (argc = 0; argv && argv[argc]; ++argc)
     {
         if (g_str_has_prefix(argv[argc], "--display="))
             display = argv[argc] + 10;
+        else if (!strcmp(argv[argc], "--display") && argv[argc + 1])
+            display = argv[argc + 1];
     }
     if (argc)
     {
         global_options_preparse_argv_for_execute(&argc, argv, TRUE);
         global_options_init(&argc, &argv, FALSE);
     }
-    roxterm_launch(display, message);
+    roxterm_launch(display, env);
 
-    for (n = 0; n < argc; ++n)
-        g_free(argv[n]);
-    g_free(argv);
+    g_strfreev(argv);
+    g_strfreev(env);
     
     return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;    
 }
@@ -161,11 +188,11 @@ gboolean listen_for_new_term(void)
             new_term_listener, global_options_lookup_int("replace") > 0);
 }
 
-static const char *abs_bin(const char *filename)
+static char *abs_bin(const char *filename)
 {
     if (g_path_is_absolute(filename))
     {
-        return filename;
+        return g_strdup(filename);
     }
     return g_build_filename(global_options_bindir, "roxterm", NULL);
 }
@@ -175,16 +202,42 @@ int main(int argc, char **argv)
     gboolean preparse_ok;
     DBusMessage *message = NULL;
     char *display = NULL;
-    const char *dpy_name;
+    const char *dpy_name = NULL;
     int n;
     gboolean launched = FALSE;
     gboolean dbus_ok;
 
+    global_options_init_appdir(argc, argv);
+    global_options_init_bindir(argv[0]);
+#if ENABLE_SM
+    if (!global_options_disable_sm)
+    {
+        session_argc = argc;
+        session_argv = g_new(char *, argc);
+        if (global_options_appdir)
+        {
+            session_argv[0] = g_build_filename(global_options_appdir,
+                    "AppRun", NULL);
+            if (!g_file_test(session_argv[0], G_FILE_TEST_IS_EXECUTABLE))
+            {
+                g_free(session_argv[0]);
+                session_argv[0] = abs_bin(argv[0]);
+            }
+        }
+        else
+        {
+            session_argv[0] = abs_bin(argv[0]);
+        }
+        for (n = 1; n < argc; ++n)
+        {
+            session_argv[n] = g_strdup(argv[n]);
+        }
+    }
+#endif
     g_set_application_name(PACKAGE);
     preparse_ok = global_options_preparse_argv_for_execute(&argc, argv, FALSE);
     
 #if ENABLE_NLS
-    global_options_init_appdir(argc, argv);
     setlocale(LC_ALL, "");
     bindtextdomain(PACKAGE, global_options_appdir ?
             g_strdup_printf("%s/locale", global_options_appdir) : LOCALEDIR);
@@ -197,6 +250,13 @@ int main(int argc, char **argv)
         if (strlen(argv[n]) > 10 && g_str_has_prefix(argv[n], "--display="))
         {
             display = g_strdup(argv[n]); 
+            dpy_name = display + 10;
+            break;
+        }
+        else if (n < argc - 1 && !strcmp(argv[n], "--display"))
+        {
+            display = g_strdup_printf("--display=%s", argv[n + 1]); 
+            dpy_name = display + 10;
             break;
         }
     }
@@ -209,9 +269,11 @@ int main(int argc, char **argv)
         return 1;
     }
     
-    dpy_name = gdk_display_get_name(gdk_display_get_default());
     if (!display)
+    {
+        dpy_name = gdk_display_get_name(gdk_display_get_default());
         display = g_strdup_printf("--display=%s", dpy_name);
+    }
     
     /* Have to create message with args from argv before parsing them */
     dbus_ok = rtdbus_ok = rtdbus_init();
@@ -267,6 +329,7 @@ int main(int argc, char **argv)
     gtk_quit_add(0, main_quit_handler, main_all_windows);
 
     roxterm_init();
+    multi_win_set_role_prefix("roxterm");
 #if ENABLE_SM
     if (!global_options_disable_sm)
     {
@@ -276,35 +339,20 @@ int main(int argc, char **argv)
             launched = session_load(global_options_clone_session_id);
     }
 #endif
-    multi_win_set_role_prefix("roxterm");
     if (!launched)
     {
-        roxterm_launch(dpy_name, NULL);
+        roxterm_launch(dpy_name, environ);
     }
 
 #if ENABLE_SM
     if (!global_options_disable_sm)
     {
-        if (global_options_appdir)
-        {
-            session_arg0 = g_build_filename(global_options_appdir,
-                    "AppRun", NULL);
-            if (!g_file_test(session_arg0, G_FILE_TEST_IS_EXECUTABLE))
-            {
-                g_free((char *) session_arg0);
-                session_arg0 = abs_bin(argv[0]);
-            }
-        }
-        else
-        {
-            session_arg0 = abs_bin(argv[0]);
-        }
         session_init(global_options_restart_session_id);
     }
 #endif
 
     gtk_main();
-
+    
     return 0;
 }
 
