@@ -24,6 +24,8 @@
 #include "menutree.h"
 #include "options.h"
 
+#define HAVE_COMPOSITE GTK_CHECK_VERSION(2, 10, 0)
+
 typedef struct MultiTab MultiTab;
 typedef struct MultiWin MultiWin;
 
@@ -41,7 +43,7 @@ typedef struct MultiWin MultiWin;
  */
 typedef GtkWidget *(*MultiTabFiller) (MultiWin * win, MultiTab * tab,
     gpointer user_data_template, gpointer * new_user_data,
-    char **title, GtkWidget ** active_widget, GtkAdjustment **adjustment);
+    GtkWidget ** active_widget, GtkAdjustment **adjustment);
 
 /* Called when a tab is destroyed, with the data passed as new_user_data above
  */
@@ -56,25 +58,27 @@ typedef void (*MultiWinMenuSignalConnector) (MultiWin * win);
 typedef void (*MultiWinGeometryFunc) (gpointer user_data, GdkGeometry * geom,
     GdkWindowHints * hints);
 
-/* Size function. pwidth and pheight point to return values for width and
- * height in pixels of the core of the widget ie minus any borders */
-typedef enum {
-    MultiWin_GetActualSize,        /* Return the current actual size of the
-                                   widget's core */
-    MultiWin_GetTargetSize,        /* Return the size it should be from
-                                   config settings or whatever */
-    MultiWin_UpdateConfiguredSize    /* User has resized window; update config
-                                       from current size */
-} MultiWinSizeReason;
-typedef void (*MultiWinSizeFunc) (gpointer user_data, MultiWinSizeReason,
-        int *pwidth, int *pheight);
+/* If pixels is FALSE: Return grid size in *pwidth and *pheight.
+ * If pixels is TRUE: Given a grid size in *pwidth and *pheight, update them to
+ * the total size of the widget required for it. If a size in is -1 use the
+ * widget's current grid size instead.
+ */
+typedef void (*MultiWinSizeFunc) (gpointer user_data, gboolean pixels,
+    int *pwidth, int *pheight);
+
+/* Return the profile's default size in char cells */
+typedef void (*MultiWinDefaultSizeFunc)(gpointer user_data,
+        int *width, int *height);
 
 /* Called when a tab is selected */
 typedef void (*MultiTabSelectionHandler) (gpointer user_data, MultiTab * tab);
 
 /* Called when a tab is dragged to a new window; should be used to try to make
- * sure page is same size as other tabs in new window */
-typedef void (*MultiTabToNewWindowHandler)(MultiWin *win, MultiTab *tab);
+ * sure page is same size as other tabs in new window and to update references.
+ * old_win_destroyed is TRUE if the tab's previous window was destroyed.
+ */
+typedef void (*MultiTabToNewWindowHandler)(MultiWin *win, MultiTab *tab,
+        gboolean old_win_destroyed);
 
 /* Called when the zoom factor is changed */
 typedef void (*MultiWinZoomHandler)(gpointer user_data, double zoom_factor,
@@ -105,22 +109,17 @@ MultiWinGetDisableMenuShortcuts multi_win_get_disable_menu_shortcuts;
 void
 multi_tab_init(MultiTabFiller filler, MultiTabDestructor destructor,
     MultiWinMenuSignalConnector menu_signal_connector,
-    MultiWinGeometryFunc, MultiWinSizeFunc, MultiTabToNewWindowHandler,
+    MultiWinGeometryFunc, MultiWinSizeFunc, MultiWinDefaultSizeFunc,
+    MultiTabToNewWindowHandler,
     MultiWinZoomHandler, MultiWinGetDisableMenuShortcuts, MultiWinInitialTabs,
-    MultiWinDeleteHandler, MultiTabGetShowCloseButton);
+    MultiWinDeleteHandler, MultiTabGetShowCloseButton
+    );
 
 /* Register a MultiTabSelectionHandler (see above) */
 void
 multi_tab_connect_tab_selection_handler(MultiWin *, MultiTabSelectionHandler);
 
-MultiTab *multi_tab_new0(MultiWin * parent, gpointer user_data_template,
-        gboolean make_current);
-
-inline static MultiTab *multi_tab_new(MultiWin *parent,
-        gpointer user_data_template)
-{
-    return multi_tab_new0(parent, user_data_template, TRUE);
-}
+MultiTab *multi_tab_new(MultiWin * parent, gpointer user_data_template);
 
 /* When all tabs are destroyed the window is destroyed too */
 void multi_tab_delete(MultiTab *);
@@ -129,14 +128,22 @@ GtkWidget *multi_tab_get_widget(MultiTab *);
 
 const char *multi_tab_get_display_name(MultiTab *tab);
 
-void multi_tab_set_window_title(MultiTab *, const char *);
-
 void multi_tab_set_icon_title(MultiTab *, const char *);
 
-void multi_tab_set_name(MultiTab *, const char *);
+/* Sets the title which is used to build the actaul title from title_template.
+ */
+void multi_tab_set_window_title(MultiTab *, const char *);
 
-const char *multi_tab_get_name(MultiTab *);
+/* See multi_win_set-title */
+void multi_tab_set_window_title_template(MultiTab *, const char *);
 
+const char *multi_tab_get_window_title_template(MultiTab *);
+
+gboolean multi_tab_get_title_template_locked(MultiTab *);
+
+void multi_tab_set_title_template_locked(MultiTab *, gboolean);
+
+/* Not the full title */
 const char *multi_tab_get_window_title(MultiTab *);
 
 const char *multi_tab_get_icon_title(MultiTab *);
@@ -160,26 +167,30 @@ inline static GtkNotebook *multi_tab_get_notebook(MultiTab *tab)
 
 /* Adds reference to widget but label and menutree widgets are lost;
  * if notify_only this function assumes the tab has already been moved by
- * GTK and it's just being called for notification */
-void multi_tab_remove_from_parent(MultiTab *tab, gboolean notify_only);
+ * GTK and it's just being called for notification.
+ * Returns TRUE if win has no tabs left and is destroyed.
+ */
+gboolean multi_tab_remove_from_parent(MultiTab *tab, gboolean notify_only);
 
 /* Moves a tab to the given position in the notebook; if reorder is TRUE
  * this function does the reordering otherwise it assumes the reordering has
  * already been done and it just updates data structs */
 void multi_tab_move_to_position(MultiTab *tab, int position, gboolean reorder);
 
-#if DO_OWN_TAB_DRAGGING
 /* Move tab to a different window */
 void multi_tab_move_to_new_window(MultiWin *win, MultiTab *tab, int position);
-#endif
 
-/* Returns NULL if pointer not over one of our tabs; otherwise position is
- * filled in with tab's position if not NULL. x and y are absolute coordinates
- * from mouse event. Note that when there are multiple tabs this returns tab
- * whose label spans pointer position, not necessarily the one whose main page
- * widget is under the pointer */
+/* Returns NULL if pointer not over one of our tabs. x and y are absolute
+ * coordinates from mouse event. Note that when there are multiple tabs this
+ * returns tab whose label spans pointer position, not necessarily the one
+ * whose main page widget is under the pointer */
 MultiTab *multi_tab_get_tab_under_pointer(int x, int y);
 
+/* widget is the top-level child of the notebook, as would be passed in a drag
+ * received event for a GtkNotebook dragged tab.
+ */
+MultiTab *multi_tab_get_from_widget(GtkWidget *widget);
+
 /* Make the tab flash orange or something */
 void multi_tab_draw_attention(MultiTab *tab);
 void multi_tab_cancel_attention(MultiTab *tab);
@@ -263,6 +274,10 @@ MultiWin *multi_win_new_blank(const char *display_name,
         gboolean disable_menu_shortcuts, gboolean disable_tab_shortcuts,
         GtkPositionType tab_pos, gboolean always_show_tabs);
 
+/* Creates a new "blank" window ready for a dragged tab at given coords */
+MultiWin *multi_win_new_for_tab(const char *display_name, int x, int y,
+        MultiTab *tab);
+
 void multi_win_show(MultiWin *win);
 
 /* Deletes a window, clearing up its data and removing it from main list, also
@@ -274,10 +289,6 @@ void
 multi_win_set_geometry_hints(MultiWin * win, GtkWidget * child,
     GdkGeometry * geometry, GdkWindowHints geom_mask);
 
-/* Set window size to fit child at given size */
-void
-multi_win_set_size(MultiWin * win, GtkWidget * child, int width, int height);
-
 void multi_win_set_fullscreen(MultiWin *win, gboolean fullscreen);
 
 GtkWidget *multi_win_get_widget(MultiWin * win);
@@ -336,9 +347,8 @@ void multi_win_set_shortcut_scheme(MultiWin * win, Options *);
 
 GtkAccelGroup *multi_win_get_accel_group(MultiWin * win);
 
-/* If resize is TRUE, force window resize to accommodate change in height */
 void
-multi_win_set_show_menu_bar(MultiWin * win, gboolean show, gboolean resize);
+multi_win_set_show_menu_bar(MultiWin * win, gboolean show);
 
 gboolean multi_win_get_show_menu_bar(MultiWin * win);
 
@@ -385,15 +395,22 @@ void multi_win_set_always_show_tabs(MultiWin *win, gboolean show);
 /* List of all known windows - treat as read-only */
 extern GList *multi_win_all;
 
-/* Sets a title template string - see profile dialog "Window/Tabs Window Title"
-   comment for details; NULL is equivalent to "%s". If def (for "default")
-   this is a default which will be restored if NULL is subsequently passed with
-   def FALSE */
-void multi_win_set_title_template(MultiWin *win, const char *tt,
-        gboolean def);
+/* Sets a title template string. %s is substituted with the current tab's title.
+ * There may only be one %s and no other % characters except %%.
+ * NULL is equivalent to "%s".
+ */
+void multi_win_set_title_template(MultiWin *win, const char *tt);
 
 const char *multi_win_get_title_template(MultiWin *win);
 
+const char *multi_win_get_title(MultiWin *win);
+
+void multi_win_set_title(MultiWin *win, const char *);
+
+void multi_win_set_title_template_locked(MultiWin *win, gboolean locked);
+
+gboolean multi_win_get_title_template_locked(MultiWin *win);
+
 /* Whether window is managed by a compositor */
 gboolean multi_win_composite(MultiWin *win);
 
