@@ -26,8 +26,6 @@
 
 #include <vte/vte.h>
 
-#include "rtdbus.h"
-
 typedef struct ROXTermData ROXTermData;
 
 /* Make sure global options have been parsed before calling this, but call it
@@ -36,9 +34,11 @@ typedef struct ROXTermData ROXTermData;
  */
 void roxterm_init(void);
 
-/* Launch a new terminal in response to a D-BUS message (launcher) or for first
- * time (launcher = NULL); display_name may be NULL for default display. */
-void roxterm_launch(const char *display_name, DBusMessage *launcher);
+/* Launch a new terminal in response to a D-BUS message or for first
+ * time; display_name may be NULL for default display.
+ * env is copied without being altered.
+ */
+void roxterm_launch(const char *display_name, char **env);
 
 /* Ways of spawning a command */
 typedef enum {
@@ -52,7 +52,7 @@ typedef enum {
 void roxterm_spawn(ROXTermData *, const char *command, ROXTerm_SpawnType);
 
 gboolean roxterm_spawn_command_line(const gchar *command_line,
-        const char *display_name, const char *cwd, GError **error);
+        const char *display_name, const char *cwd, char **env, GError **error);
 
 VteTerminal *roxterm_get_vte_terminal(ROXTermData *roxterm);
 
